@@ -1,7 +1,11 @@
 """Constants for the fibaro client."""
 
 # Timeout in seconds for http requests
-TIMEOUT = 10
+DEFAULT_TIMEOUT = 10
+
+# HC 3 needs a big timeout for refresh states request,
+# it waits up to 30 seconds before a response is sent
+REFRESH_STATE_TIMEOUT = 35
 
 # Constant http headers sent with each request
 HTTP_HEADERS = {
@@ -10,7 +14,7 @@ HTTP_HEADERS = {
 }
 
 # Match serial number prefix to a interface version
-API_VERSION_MATCHER = {"HC2": 4, "HCL": 4, "HC3": 5, "HC3L": 5, "YH": 5}
+API_VERSION_MATCHER = {"HC2": 4, "HCL": 4, "HC3": 5, "HC3L": 5, "YH": 5, "ZB": 5}
 
 # Devices which are ignored
 # iOS_device includes iOS and Android devices
